*******
Authors
*******

Leads
=====

- Jérôme Lafréchoux  `@lafrech <https://github.com/lafrech>`_
- David Fédérique `@davidfrederique <https://github.com/davidfrederique>`_

Contributors (chronological)
============================

- Ryan Yin `@ryan4yin <https://github.com/ryan4yin>`_
- Douglas Thor `@dougthor42 <https://github.com/dougthor42>`_
- Steven Loria `@sloria <https://github.com/sloria>`_
- Jón Bjarnason `@nonnib <https://github.com/nonnib>`_
- Igor Davydenko `@playpauseandstop <https://github.com/playpauseandstop>`_
- Joshua Harrison `@joshua-harrison-2011 <https://github.com/joshua-harrison-2011>`_
- Martin Roy `@lindycoder <https://github.com/lindycoder>`_
- Martijn Pieters `@mjpieters <https://github.com/mjpieters>`_
- Stephen Rosen `@sirosen <https://github.com/sirosen>`_
- Grey Li `@greyli <https://github.com/greyli>`_
- Tim Diekmann `@TimDiekmann <https://github.com/TimDiekmann>`_
- Choudhury Noor `@Cnoor0171 <https://github.com/Cnoor0171>`_
- Dmitry Erlikh `@derlikh-smart <https://github.com/derlikh-smart>`_
- 0x78f1935 `@0x78f1935 <https://github.com/0x78f1935>`_
